@@ -28,9 +28,9 @@ fi
 
 echo Converting $1 to PDF...
 
-tempfile=PStoPDFviewer_$$
+tempfile=PStoPDFviewer_$$.pdf
 ps2pdf $1 $tempfile
 
 #ls -l ./$tempfile
 
-($ACE_PDF_COMMAND $tempfile; $RM_CMD -f $tempfile) &
+($ACE_PDF_COMMAND $tempfile; wait; $RM_CMD -f $tempfile) &
