@@ -22,6 +22,8 @@ import java.io.IOException;
 import java.io.InputStreamReader;
 import java.io.OutputStreamWriter;
 import java.io.StringReader;
+import javax.swing.Box;
+import javax.swing.BoxLayout;
 import org.biolegato.core.data.seqdoc.SeqDoc;
 import org.biolegato.core.plugins.PluginLoader;
 import org.biolegato.core.data.sequence.Sequence;
@@ -86,7 +88,7 @@ public final class BLMain {
     /**
      * This constant is used to keep track of version changes.
      */
-    public static final String VERSION = "0.6.2";
+    public static final String VERSION = "0.7.0";
     /**
      * The default font for BioLegato
      */
@@ -124,6 +126,10 @@ public final class BLMain {
      * the current data selection.
      */
     private static JTabbedPane canvasPane = null;
+    /**
+     * Stores the main menu for the program
+     */
+    private static JMenuBar menu = null;
     /**
      * Stores all of the menu headings in BioLegato's main window.
      * This hashtable is used to add menu items to BioLegato's menu headings.
@@ -151,15 +157,16 @@ public final class BLMain {
 //////////////////////////
         DataCanvas currentCanvas = null;    // used for loading canvases (for testing proper object creation)
         MenuType currentMenuLoader = null;  // used for menu plugins
-	
+
 /////////////////////////
 //*********************//
 //* PROCESS ARGUMENTS *//
 //*********************//
 /////////////////////////
+	
         // load the properties, plugins and file formats
 	properties = new BLProperties();
-        PluginLoader.loadPlugins(getProperty("plugins"));
+        PluginLoader.loadPlugins(envreplace(getProperty("plugins")));
         processArgs(args);
 
         // load properties extensions
@@ -178,8 +185,16 @@ public final class BLMain {
 	window = new JFrame(NAME);
 	
 	// add tabbed pane to window
+	menu = new JMenuBar();
+	Box displayBox = new Box(BoxLayout.PAGE_AXIS);
+	window.setJMenuBar(menu);
+	//JToolBar toolBar = new JToolBar();
+	//toolBar.add(menu);
+	//displayBox.add(toolBar);
+	//displayBox.add(new JScrollPane(menu));
+	//displayBox.add(canvasPane);
+	//window.add(displayBox);
 	window.add(canvasPane);
-        window.setJMenuBar(new JMenuBar());
 	
 ////////////
 //********//
@@ -415,16 +430,17 @@ public final class BLMain {
     private static void processArgs (String[] args) {
         String value = "";	    // the value of the current argument parameter
         File fileIn = null;	    //
+	String argument = null;	    //
         Sequence[] dataIn = null;   //
 
         // ensure that args is not null
         if (args != null) {
             // itterate through the command arguments
-            for (String argument : args) {
+            for (String rawarg : args) {
                 // discard null arguments
-                if (argument != null) {
-                    // create a new file object to test if the argument is a file
-                    fileIn = new File(argument);
+                if (rawarg != null) {
+		    // create a new file object to test if the argument is a file
+		    fileIn = new File(rawarg);
 
                     // if the argument is a file name then read the file; otherwise,
                     // parse the argument
@@ -432,8 +448,11 @@ public final class BLMain {
                         fileIn.canRead()) {
                         addData(org.biolegato.core.plugintypes.DataFormat.auto(
                                 fileIn));
-                    } else if (argument.startsWith("/") || argument.startsWith(
+                    } else if (rawarg.startsWith("/") || rawarg.startsWith(
                             "-")) {
+			// copy the command line argument
+			argument = rawarg;
+
                         // trim the argument
                         if (argument.startsWith("--") && argument.length() > 2) {
                             argument = argument.substring(2);
@@ -446,8 +465,7 @@ public final class BLMain {
                         // If there is an equals '=' sign then the argument has a value.  Set the value
                         // variable to the arguments' value for further parsing
                         if (argument.indexOf('=') > 0) {
-                            value =
-                            argument.substring(argument.indexOf('=') + 1);
+                            value = argument.substring(argument.indexOf('=') + 1);
                             argument = argument.substring(0, argument.indexOf(
                                     '='));
                         }
@@ -502,6 +520,9 @@ public final class BLMain {
                                     "NAME\n" +
                                     "    Bio Legato - A customizable GUI for running programs\n" +
                                     "\n" +
+                                    "VERSION\n" +
+                                    "    Version " + VERSION + "\n" +
+                                    "\n" +
                                     "SYNOPSIS\n" +
                                     "    biolegato [options] [files]\n" +
                                     "\n" +
@@ -536,8 +557,8 @@ public final class BLMain {
                                     "        Displays a list of loaded plugins\n" +
                                     "    properties\n" +
                                     "        Displays a list of BioLegato's properties\n" +
-                                    "\n" +
-                                    "EXAMPLES\n" +
+				    "\n" +
+                                    "USAGE EXAMPLES\n" +
                                     "    biolegato\n" +
                                     "\n" +
                                     "    biolegato insequence.gb\n" +
@@ -548,30 +569,86 @@ public final class BLMain {
                                     "\n" +
                                     "    biolegato --plugins --properties --debug\n" +
                                     "\n" +
-                                    "    biolegato --plugins --properties --debug insequence.gb\n" +
+                                    "    biolegato --plugins /properties -debug insequence.gb\n" +
+                                    "\n" +
+				    "ENVIRONMENT VARIABLES\n" +
+				    "    BioLegato searches for the following environment variables.  If they don't exist BioLegato sets them to defaults.\n" +
+				    "\n" +
+				    "      BIOLEGATO_HOME\n" +
+				    "        Default: the path of the current working directory\n" +
+				    "        Description: the path to reference BioLegato from\n" +
+				    "\n" +
+				    "      BIOLEGATO_COLOURMASK_DIR\n" +
+				    "        Default: uses .blproperties value\n" +
+				    "        Description: the directory to populate the default colourmask\n" +
+				    "                     list\n" +
+				    "\n" +
+				    "      GDE_HELP_DIR\n" +
+				    "        Default: null\n" +
+				    "        Description: specifies a path to search for the main .GDEmenus file\n" +
+				    "                     (NOTE: this is GDE_Menus.jar plugin specific)\n" +
+				    "\n" +
+				    "PROPERTIES\n" +
+				    "    BioLegato supports the followind properties:\n" +
+				    "\n" +
+				    "      Property             Description\n" +
+				    "        debug                determines whether or not to display debug information\n" +
+				    "        plugins              sets the plugin directory\n" +
+				    "        temp                 sets the temporary files directory\n" +
+				    "        font.size            determines the default font size for objects in BioLegato\n" +
+				    "        font.type            determines the default font type for objects in BioLegato\n" +
+				    "        shell.name           determines the shell to execute\n" +
+				    "        shell.parameter      determines the parameter for directing the shell to execute a command\n" +
+				    "        pwd.properties       determines whether or not to read the properties file located in the current working directory\n" +
+				    "        user.properties      determines whether or not to read the user's propery files (located in the user's home directory\n" +
+				    "        user.plugins         determines whether or not to read the user's plugin files (located in the user's home directory\n" +
+				    "        default.canvas       determines the default canvas to show on startup\n" +
+				    "        default.fileformat   determines the default file format for open/save dialogs\n" +
+				    "        GDE.menu             determines whether or not to read the GDE menu files (backwards compatibility mode)\n" +
+				    "        GDE.help.viewer      determines which file to feed the help file to\n" +
+				    "        GDE.help.path        the location to search for the help files\n" +
+				    "        undo                 whether or not to enable undo support\n" +
+				    "        undo.size            whether or not to enable undo support\n" +
+				    "\n" +
+				    "    This properties class will read properties files from the directory containing BioLegato, the user directory and finally\n" +
+				    "    the directory BioLegato was launched from.  Please note that you can disable reading of properties files\n" +
+				    "    from the user directory via. \"user.properties\"; likewise you can disable reading properties files in the directory BioLegato\n" +
+				    "    was launched from via. \"pwd.properties\"" +
+				    "\n" +
+				    "    NOTE: for path properties BioLegato will replace all $'s with the appropriate environment variables if set.\n" +
                                     "\n" +
                                     "SUPPORTED PLUGINS\n" +
                                     "    Currently BioLegato supports the following main types of Plugins:\n" +
                                     "\n" +
                                     "        Canvases\n" +
-                                    "           extends the class: Plugins.DataCanvases\n" +
-                                    "        File formats" +
-                                    "           extends the class: Plugins.DataFormat\n" +
+                                    "           extends the class: org.biolegato.core.plugintypes.DataCanvas\n" +
+                                    "        File formats\n" +
+                                    "           extends the class: org.biolegato.core.plugintypes.DataFormat\n" +
                                     "        Menu types\n" +
-                                    "           extends the class: Plugins.MenuType\n" +
+                                    "           extends the class: org.biolegato.core.plugintypes.MenuType\n" +
+                                    "        Properties\n" +
+                                    "           extends the class: org.biolegato.core.plugintypes.PropertiesExtension\n" +
                                     "\n" +
                                     "    For more information about plugins, please consult the BioLegato API\n" +
                                     "\n" +
                                     "FILES\n" +
                                     "    biolegato\n" +
                                     "        Script to run BioLegato\n" +
-                                    "    BioLegato.jar\n" +
+                                    "    biolegato.jar\n" +
                                     "        BioLegato's core java code\n" +
-                                    "    Plugins/GDE.jar" +
-                                    "        Provides backward compatibility with GDE\n" +
-                                    "    Plugins/GenBankFile2008.class" +
+                                    "    changelog.txt\n" +
+                                    "        BioLegato's revision history\n" +
+                                    "    plugins/GDE_Menu.jar" +
+                                    "        Provides backward compatibility with GDE menus\n" +
+                                    "    plugins/GDE_anvas.jar" +
+                                    "        Provides GDE style multiple alignment canvas\n" +
+                                    "    plugins/GDEFile.class" +
+                                    "        Provides internal file support for GDE files\n" +
+                                    "    plugins/GDEFlatFile.class" +
+                                    "        Provides internal file support for GDE flatfiles\n" +
+                                    "    plugins/GenBankFile2008.class" +
                                     "        Provides internal file support for GenBank files (2008 standard copliant)\n" +
-                                    "    Plugins/FastA.class" +
+                                    "    plugins/FastA.class" +
                                     "        Provides internal file support for FastA files\n" +
                                     "\n" +
                                     "FILE FORMATS\n" +
@@ -670,7 +747,7 @@ public final class BLMain {
                             // show BioLegato's current settings
                             properties.list(System.out);
                         } else {
-                            BLMain.error("Unknown argument: " + argument,
+                            BLMain.error("Unknown argument: " + rawarg,
                                          "processArgs");
                         }
                     }
@@ -723,21 +800,28 @@ public final class BLMain {
     public static Sequence[] getClipboard () {
 	String string = "";
 	Sequence[] clipboard = null;
+	Sequence[] result = null;
         Transferable t = Toolkit.getDefaultToolkit().getSystemClipboard().getContents(null);
     
         try {
             if (t != null) {
 		if (t.isDataFlavorSupported(SeqDoc.seqDocFlavour)) {
 		    clipboard = ((SeqDoc)t.getTransferData(SeqDoc.seqDocFlavour)).toArray();
+		    
+		    // clone clipboard sequences
+		    result = new Sequence[clipboard.length];
+		    for (int count = 0; count < clipboard.length; count++) {
+			result[count] = new Sequence(clipboard[count]);
+		    }
 		} else if (t.isDataFlavorSupported(DataFlavor.stringFlavor)) {
 		    string = (String)t.getTransferData(DataFlavor.stringFlavor);
-		    clipboard = DataFormat.auto(new BufferedReader(new StringReader(string)));
+		    result = DataFormat.auto(new BufferedReader(new StringReader(string)));
 		}
             }
         } catch (UnsupportedFlavorException e) {
         } catch (IOException e) {
         }
-	return clipboard;
+	return result;
     }
     
     /**
@@ -831,7 +915,7 @@ public final class BLMain {
 
             // add the heading
             menuHeadings.put(name, heading);
-            window.getJMenuBar().add(heading);
+            menu.add(heading);
         }
 
         // return the menu heading object
@@ -849,9 +933,9 @@ public final class BLMain {
         JMenu heading = addMenuHeading(name);	// the hading to add the item to.
 
         // ensure that the menu heading is in the correct order
-        if (window.getJMenuBar().getComponentIndex(heading) != order) {
-            window.getJMenuBar().remove(heading);
-            window.getJMenuBar().add(heading, order);
+        if (menu.getComponentIndex(heading) != order) {
+            menu.remove(heading);
+            menu.add(heading, order);
         }
         return heading;
     }
@@ -1130,4 +1214,49 @@ public final class BLMain {
 	}
 	return result;
     }
+    
+    /**
+     * Replaces $VARIABLE name with environment variables.
+     * This function provides functionality similar to BASH.
+     *
+     * NOTE: if the variable is $BIOLEGATO_HOME, and this is not set, 
+     *	the variable will default to the current working directory.
+     *
+     * @param change the string to modify.
+     * @return the modified string.
+     */
+    public static String envreplace(String change) {
+	int start = 0;
+	int end = -1;
+	String replace = null;
+	String variable = "";
+	
+	if (change != null) {
+	    while ((start = change.indexOf('$', start)) >= start && start > -1) {
+		for (end = start + 1; end < change.length() && (change.charAt(end) == '_' || Character.isLetter(change.charAt(end))); end++);
+		    /* ITTERATE */
+
+		// get the information to perform the string replacement.
+		variable = change.substring(start + 1, end);
+		replace = System.getenv(variable);
+		
+		// ensure BIOLEGATO_HOME is set properly.
+		if (variable.equalsIgnoreCase("BIOLEGATO_HOME")) {
+		    if (replace == null || "".equals(replace.trim()) || !new File(replace).exists()) {
+			replace = BLMain.CURRENT_DIR;
+		    } else {
+			replace = new File(replace).getAbsolutePath();
+		    }
+		}
+		
+		// perform the string replacement.
+		if (replace != null) {
+		    change = change.substring(0, start) + replace + change.substring(end);
+		} else {
+		    start++;
+		}
+	    }
+	}
+	return change;
+    }
 }
