@@ -20,20 +20,13 @@ import org.biolegato.core.main.BLMain;
  * @author Brian Fristensky
  */
 public abstract class DataCanvas extends Box implements ChangeListener {
-	/**
-	 * The program window to use to obtain program data from.
-	 */
-	protected BLMain program = null;
-
 	/**
 	 * Creates a new instance of BLCanvas
 	 * 
-	 * @param program the BioLegato instance to attach the canvas to.
 	 * @param alignment the alignment for the box.
 	 */
-	protected DataCanvas (BLMain program, int alignment) {
+	protected DataCanvas (int alignment) {
 		super(alignment);
-		this.program = program;
 	}
 
 	/**
@@ -51,9 +44,9 @@ public abstract class DataCanvas extends Box implements ChangeListener {
 	 * @return the complete contents of the data in the canvas
 	 */
 	public final Sequence[] getAllData () {
-		Sequence[] result = new Sequence[program.getSeqDoc().getLineCount()];
-		for (int line = 0; line < program.getSeqDoc().getLineCount(); line++) {
-			result[line] = program.getSeqDoc().getSequence(line);
+		Sequence[] result = new Sequence[BLMain.getSeqDoc().getLineCount()];
+		for (int line = 0; line < BLMain.getSeqDoc().getLineCount(); line++) {
+			result[line] = BLMain.getSeqDoc().getLine(line);
 		}
 		return result;
 	}
