@@ -16,6 +16,7 @@ import javax.swing.Box;
 import javax.swing.BoxLayout;
 import javax.swing.JButton;
 import javax.swing.JDialog;
+import javax.swing.JFrame;
 import org.biolegato.core.main.BLMain;
 import org.biolegato.core.plugins.PluginLoader;
 import org.biolegato.core.plugins.PluginWrapper;
@@ -34,15 +35,25 @@ import org.biolegato.core.plugintypes.PropertiesExtension;
  *	<tr><td>font.type</td>              <td>Yes</td>                <td>determines the default font type for objects in BioLegato</td></tr>
  *	<tr><td>shell.name</td>             <td>Yes</td>                <td>determines the shell to execute</td></tr>
  *	<tr><td>shell.parameter</td>        <td>Yes</td>                <td>determines the parameter for directing the shell to execute a command</td></tr>
+ *	<tr><td>pwd.properties</td>         <td>Yes</td>                <td>determines whether or not to read the properties file located in the current working directory</td></tr>
  *	<tr><td>user.properties</td>        <td>Yes</td>                <td>determines whether or not to read the user's propery files (located in the user's home directory</td></tr>
- *	<tr><td>user.properties</td>        <td>Yes</td>                <td>determines whether or not to read the user's plugin files (located in the user's home directory</td></tr>
+ *	<tr><td>user.plugins</td>	    <td>Yes</td>                <td>determines whether or not to read the user's plugin files (located in the user's home directory</td></tr>
  *	<tr><td>default.canvas</td>         <td>Yes</td>                <td>determines the default canvas to show on startup</td></tr>
  *	<tr><td>default.fileformat</td>     <td>Yes</td>                <td>determines the default file format for open/save dialogs</td></tr>
  *	<tr><td>GDE.menu</td>               <td>No</td>                 <td>determines whether or not to read the GDE menu files (backwards compatibility mode)</td></tr>
  *	<tr><td>GDE.help.viewer</td>        <td>No</td>                 <td>determines which file to feed the help file to</td></tr>
  *	<tr><td>GDE.help.path</td>          <td>No</td>                 <td>the location to search for the help files</td></tr>
+ *	<tr><td>undo</td>		    <td>No</td>                 <td>whether or not to enable undo support</td></tr>
+ *	<tr><td>undo.size</td>		    <td>No</td>                 <td>whether or not to enable undo support</td></tr>
  * </table>
  * 
+ * This properties class will read properties files from the directory containing BioLegato, the user directory and finally
+ * the directory BioLegato was launched from.  Please note that you can disable reading of properties files
+ * from the user directory via. "user.properties"; likewise you can disable reading properties files in the directory BioLegato
+ * was launched from via. "pwd.properties"
+ *
+ * NOTE: for path properties BioLegato will replace all $'s with the appropriate environment variables if set.
+ *
  * @author Graham Alvare
  * @author Brian Fristensky
  */
@@ -81,11 +92,11 @@ public class BLProperties extends Properties {
                 setProperty("debug", "false");
                 /* sets the plugin directory */
                 setProperty("plugins",
-                            org.biolegato.core.main.BLMain.PROGRAM_DIR +
+                            BLMain.PROGRAM_DIR +
                             File.separator + "plugins");
                 /* sets the temporary file directory */
                 setProperty("temp",
-                            org.biolegato.core.main.BLMain.CURRENT_DIR);
+                            BLMain.CURRENT_DIR);
                 /* determines the default font size */
                 setProperty("font.size", "12");
                 /* determines the default font type */
@@ -98,10 +109,16 @@ public class BLProperties extends Properties {
                 /* determines the parameter for directing the shell to execute a command */
                 setProperty("shell.parameter", (System.getProperty("os.name").startsWith("Windows")
                                                 ? "/C" : "-c"));
+                /* determines whether or not to read any propery files located in the current directory */
+                setProperty("pwd.properties", "true");
                 /* determines whether or not to read the user's propery files (located in the user's home directory */
                 setProperty("user.properties", "true");
                 /* determines whether or not to read the user's plugin files (located in the user's home directory */
                 setProperty("user.plugins", "true");
+                /* determines whether or not to enable undo/redo support */
+                setProperty("undo", "false");
+                /* determines the maximum size for the undo stack */
+                setProperty("undo.size", "5");
                 /* determines the default canvas to show on startup */
                 setProperty("default.canvas", "Raw");
                 /* determines the default fileformat for all open/save dialogs */
@@ -118,13 +135,16 @@ public class BLProperties extends Properties {
         reset();
 
         // read properties files
-        loadPropertiesFile(org.biolegato.core.main.BLMain.PROGRAM_DIR +
+        loadPropertiesFile(BLMain.PROGRAM_DIR +
                            File.separator + ".blproperties");
-        if ("true".equalsIgnoreCase(getProperty("user.properties")) &&
+        if (!"false".equalsIgnoreCase(getProperty("user.properties")) &&
             System.getProperty("user.home") != null) {
             loadPropertiesFile(System.getProperty("user.home") + File.separator +
                                ".blproperties");
         }
+        if (!"false".equalsIgnoreCase(getProperty("pwd.properties"))) {
+            loadPropertiesFile("." + File.separator + ".blproperties");
+        }
     }
 
     /**
@@ -136,21 +156,26 @@ public class BLProperties extends Properties {
      */
     @Override
     public Object setProperty (String key, String value) {
-        // make sure the key is always lower case
-        key = key.toLowerCase();
+        Object result = null;
 
-        Object result = super.setProperty(key, value);  // the old value of the property changed
-        LinkedList<PropertiesListener> listenerList;    // the listener list for sending listener events.
+	// ensure that the key and value parameters are not null
+	if (key != null && value != null) {
+	    // make sure the key is always lower case
+	    key = key.toLowerCase();
+	    
+	    result = super.setProperty(key, value);  // the old value of the property changed
+	    LinkedList<PropertiesListener> listenerList;    // the listener list for sending listener events.
 
-        // obtain the list of listeners to send an event update to
-        listenerList = propertiesListeners.get(key.toLowerCase());
+	    // obtain the list of listeners to send an event update to
+	    listenerList = propertiesListeners.get(key.toLowerCase());
 
-        // send the listener event update
-        if (listenerList != null &&  ! listenerList.isEmpty()) {
-            for (PropertiesListener listener : listenerList) {
-                listener.propertiesUpdate(key, value);
-            }
-        }
+	    // send the listener event update
+	    if (listenerList != null &&  ! listenerList.isEmpty()) {
+		for (PropertiesListener listener : listenerList) {
+		    listener.propertiesUpdate(key, value);
+		}
+	    }
+	}
 
         // return the function
         return result;
@@ -207,6 +232,91 @@ public class BLProperties extends Properties {
         /* the location to search for the help files */
         setProperty("GDE.help.path", (System.getenv("GDE_HELP_DIR") != null ? System.getenv("GDE_HELP_DIR")
                                       : ""));
+	/*
+	 * DEFAULT GDE COLOURS
+	 */
+	// Red
+	setProperty("GDE.colour.1.red", "255");
+	setProperty("GDE.colour.1.green", "0");
+	setProperty("GDE.colour.1.blue", "0");
+	
+	// Orange
+	setProperty("GDE.colour.2.red", "240");
+	setProperty("GDE.colour.2.green", "180");
+	setProperty("GDE.colour.2.blue", "20");
+	
+	// Blue
+	setProperty("GDE.colour.3.red", "0");
+	setProperty("GDE.colour.3.green", "0");
+	setProperty("GDE.colour.3.blue", "255");
+	
+	// Black
+	setProperty("GDE.colour.4.red", "0");
+	setProperty("GDE.colour.4.green", "0");
+	setProperty("GDE.colour.4.blue", "0");
+	
+	// Green
+	setProperty("GDE.colour.5.red", "0");
+	setProperty("GDE.colour.5.green", "200");
+	setProperty("GDE.colour.5.blue", "0");
+	
+	// Pink
+	setProperty("GDE.colour.6.red", "255");
+	setProperty("GDE.colour.6.green", "0");
+	setProperty("GDE.colour.6.blue", "160");
+	
+	// Tirquoise
+	setProperty("GDE.colour.7.red", "0");
+	setProperty("GDE.colour.7.green", "160");
+	setProperty("GDE.colour.7.blue", "200");
+	
+	// Cyan
+	setProperty("GDE.colour.8.red", "0");
+	setProperty("GDE.colour.8.green", "127");
+	setProperty("GDE.colour.8.blue", "255");
+	
+	// Olive 2
+	setProperty("GDE.colour.9.red", "105");
+	setProperty("GDE.colour.9.green", "139");
+	setProperty("GDE.colour.9.blue", "30");
+	
+	// Purple
+	setProperty("GDE.colour.10.red", "128");
+	setProperty("GDE.colour.10.green", "0");
+	setProperty("GDE.colour.10.blue", "255");
+	
+	// Blue-grey
+	setProperty("GDE.colour.11.red", "125");
+	setProperty("GDE.colour.11.green", "158");
+	setProperty("GDE.colour.11.blue", "192");
+	
+	// Dark yellow
+	setProperty("GDE.colour.12.red", "205");
+	setProperty("GDE.colour.12.green", "205");
+	setProperty("GDE.colour.12.blue", "0");
+	
+	// Deep pink
+	setProperty("GDE.colour.13.red", "139");
+	setProperty("GDE.colour.13.green", "10");
+	setProperty("GDE.colour.13.blue", "80");
+	
+	// Burnt sienna
+	setProperty("GDE.colour.14.red", "233");
+	setProperty("GDE.colour.14.green", "116");
+	setProperty("GDE.colour.14.blue", "81");
+	
+	// Medium tirquoise
+	setProperty("GDE.colour.15.red", "0");
+	setProperty("GDE.colour.15.green", "180");
+	setProperty("GDE.colour.15.blue", "127");
+	
+	// Charteuse (med)
+	setProperty("GDE.colour.16.red", "127");
+	setProperty("GDE.colour.16.green", "230");
+	setProperty("GDE.colour.16.blue", "0");
+	
+	setProperty("seqcolourdir", BLMain.PROGRAM_DIR +
+                            File.separator + "colourmasks");
     }
 
     /**
@@ -227,7 +337,7 @@ public class BLProperties extends Properties {
      *
      * @param window the main program window to display the properties.
      */
-    public void showPropertiesWindow (BLMain window) {
+    public void showPropertiesWindow (JFrame window) {
         final JDialog propertiesWindow = new JDialog(window);
         final Box outerPane = new Box(BoxLayout.PAGE_AXIS);
         final Box mainPane = new Box(BoxLayout.PAGE_AXIS);
@@ -238,7 +348,7 @@ public class BLProperties extends Properties {
 
             public void actionPerformed (ActionEvent e) {
                 // close the properties window
-                propertiesWindow.setVisible(false);
+		propertiesWindow.dispose();
             }
 
         });
@@ -260,6 +370,7 @@ public class BLProperties extends Properties {
         propertiesWindow.setLocationRelativeTo(window);
         propertiesWindow.pack();
         propertiesWindow.setVisible(true);
+	propertiesWindow.setDefaultCloseOperation(JDialog.DISPOSE_ON_CLOSE);
     }
 
     /**
