@@ -15,6 +15,7 @@ import javax.swing.JComponent;
 import org.biolegato.core.data.seqdoc.SeqDoc;
 import org.biolegato.core.data.seqdoc.SeqDocListener;
 import org.biolegato.gdesupport.canvas.*;
+import org.biolegato.gdesupport.canvas.colourmap.CharacterColourMap;
 import org.biolegato.gdesupport.canvas.colourmap.ColourMap;
 import org.biolegato.gdesupport.canvas.colourmap.MonochromeColourMap;
 import org.biolegato.gdesupport.canvas.listeners.CursorListener;
@@ -337,55 +338,63 @@ public class BLTextArea extends BLComponent implements FocusListener, Editable,S
      */
     @Override
     public void paintComponent (Graphics gfx) {
-        final Rectangle area = gfx.getClipBounds();   // get the area to paint
-	final int x = area.x;
-	final int y = area.y;
-	final int width = area.width;
-	final int height = area.height;
-        final int startrow = Y2Row(y);
-        final int endrow = Math.min(BLMain.getSeqDoc().getLineCount(), startrow + Y2Row(height) + 1);
-        final int startcol = X2Column(x);
-        final int endcol = startcol + X2Column(width) + 1;
-        final int xstart = column2X(startcol);
-        final int ystart = row2Y(startrow);
-	// get the selection start position
-	final int startSelect = Math.max(0, getMinSX() - startcol);
-	final int endSelect = Math.max(0, getMaxSX() - startcol);
-        Sequence currentLine;
+	try {
+	    final Rectangle area = gfx.getClipBounds();   // get the area to paint
+	    final int x = area.x;
+	    final int y = area.y;
+	    final int width = area.width;
+	    final int height = area.height;
+	    final int startrow = Y2Row(y);
+	    final int endrow = Math.min(BLMain.getSeqDoc().getLineCount(), startrow + Y2Row(height) + 1);
+	    final int startcol = X2Column(x);
+	    final int endcol = startcol + X2Column(width);
+	    final int xstart = column2X(startcol);
+	    final int ystart = row2Y(startrow);
+	    // get the selection start position
+	    final int startSelect = getMinSX();
+	    final int endSelect = getMaxSX();
+	    Sequence currentLine;
+	    ColourMap useMap = currentMap;
 
-        if (gfx != null) {
-            // print the background
-            gfx.setColor(getBackground());
-            gfx.fillRect(xstart, ystart, width, height);
+	    if (gfx != null) {
+		// print the background
+		gfx.setColor(getBackground());
+		gfx.fillRect(xstart, ystart, width, height);
 
-            // print each sequence
-            for (int count = startrow; count < endrow; count ++) {
-                // get the data to print
-                currentLine = BLMain.getSeqDoc().getLine(count);
+		// print each sequence
+		for (int count = startrow; count < endrow; count ++) {
+		    // get the data to print
+		    currentLine = BLMain.getSeqDoc().getLine(count);
 
-                // substring the data to fit the area to print
-                currentLine = currentLine.subseq(startcol, endcol);
-                
-		// print the sequence (selected)
-		String string = currentLine.get("sequence").toString();
+		    // set the current colour map to the default current colour map
+		    useMap = currentMap;
 
-		if (isSelectedLine(count) && startSelect < string.length()) {
-		    // draw the sequences
-		    currentMap.regularDrawString(this, gfx, xstart, row2Y(count), currentLine.subseq(0, startSelect));
-		    currentMap.selectDrawString(this, gfx, xstart + Math.round(columnSize() * startSelect), row2Y(count), currentLine.subseq(startSelect, Math.min(string.length(), endSelect)));
-		    currentMap.regularDrawString(this, gfx, xstart + Math.round(columnSize() * endSelect), row2Y(count), currentLine.subseq(Math.min(string.length(), endSelect)));
-		} else {
-		    currentMap.regularDrawString(this, gfx, xstart, row2Y(count), currentLine);
+		    // use the sequence specific colour masks if available
+		    if (hasFocus() && currentLine.containsKey("mask") && currentLine.get("mask") instanceof ColourMap) {
+			useMap = (ColourMap)currentLine.get("mask");
+		    }
+
+		    if (isSelectedLine(count) && startcol < endSelect && endSelect >= 0 && startSelect >= 0 && endSelect - startSelect > 0) {
+			// draw the sequences
+			useMap.regularDrawString(this, gfx, xstart, row2Y(count), currentLine, startcol, startSelect);
+			useMap.selectDrawString(this, gfx, xstart + Math.round(columnSize() * Math.max(0, startSelect - startcol)), row2Y(count), currentLine, Math.max(startcol, startSelect), endSelect);
+			useMap.regularDrawString(this, gfx, xstart + Math.round(columnSize() * Math.max(0, endSelect - startcol)), row2Y(count), currentLine, endSelect, endcol);
+		    } else {
+			useMap.regularDrawString(this, gfx, xstart, row2Y(count), currentLine, startcol, endcol);
+		    }
 		}
-            }
 
-            // draw the cursor.
-            if (hasFocus() && column2X(column) >= x && column2X(column) <= x + width
-                    && row2Y(row) >= y && row2Y(row + 1) <= y + height) {
-                gfx.setColor(getForeground());
-                gfx.drawLine(column2X(column), row2Y(row), column2X(column), row2Y(row + 1));
-            }
-        }
+		// draw the cursor.
+		if (hasFocus() && column2X(column) >= x && column2X(column) <= x + width
+			&& row2Y(row) >= y && row2Y(row + 1) <= y + height) {
+		    gfx.setColor(getForeground());
+		    gfx.drawLine(column2X(column), row2Y(row), column2X(column), row2Y(row + 1));
+		}
+	    }
+	} catch (Throwable th) {
+	    // don't halt printing other objects on crash
+	    th.printStackTrace();
+	}
     }
 
     /**
@@ -776,11 +785,8 @@ public class BLTextArea extends BLComponent implements FocusListener, Editable,S
      * Selects all the sequences within the textarea.
      */
     public void selectAll() {
-        changePosition(0, 0);
         moveSelection(0, 0);
-        changePosition(column, BLMain.getSeqDoc().getLineCount() - 1);
-        changePosition(BLMain.getSeqDoc().getLineLength(row), row);
-        stretchSelection(column, row);
+        stretchSelection(BLMain.getSeqDoc().getLongestLine(), BLMain.getSeqDoc().getLineCount() - 1);
     }
 
 /////////////////////////////////////
