@@ -11,6 +11,7 @@ import org.biolegato.core.data.sequence.Sequence;
 import org.biolegato.core.data.sequence.Sequence.Type;
 import org.biolegato.core.data.sequence.Sequence.Topology;
 import org.biolegato.core.data.sequence.Sequence.Strandedness;
+import org.biolegato.core.main.BLMain;
 import org.biolegato.core.plugintypes.DataFormat;
 import java.io.File;
 import java.io.IOException;
@@ -50,9 +51,9 @@ public class GenBankFile2008 extends DataFormat {
         // translate the data
         // NOTE: append is faster than + or concat operators
         if (seq != null) {
-	    sequence = seq.getField("sequence").toString();
-            if ( Boolean.TRUE.equals(seq.getField("modified")) || "".equals(seq.getField("originalgb"))) {
-		result.append("LOCUS       ").append((seq.getField("name").toString() +
+	    sequence = seq.get("sequence").toString();
+            if ( Boolean.TRUE.equals(seq.get("modified")) || "".equals(seq.get("originalgb"))) {
+		result.append("LOCUS       ").append((seq.get("name").toString() +
 						      "                ").substring(
 			0, 16)).append(" ");
 
@@ -61,48 +62,48 @@ public class GenBankFile2008 extends DataFormat {
 								sequenceLength.length() -
 								11)));
 
-		if ( ! Type.PROTEIN.equals(seq.getField("type"))) {
+		if ( ! Type.PROTEIN.equals(seq.get("type"))) {
 		    result.append(" bp ");
-		    if (seq.getField("strandedness") != null && seq.getField("strandedness") instanceof Strandedness) {
-			result.append(getGBStrandedness((Strandedness)seq.getField("strandedness"))).append("-");
-			result.append((Type.DNA.equals(seq.getField("type")) ? "DNA     " : "RNA     "));
+		    if (seq.get("strandedness") != null && seq.get("strandedness") instanceof Strandedness) {
+			result.append(getGBStrandedness((Strandedness)seq.get("strandedness"))).append("-");
+			result.append((!Type.RNA.equals(seq.get("type")) ? "DNA     " : "RNA     "));
 		    } else {
-			result.append((Type.DNA.equals(seq.getField("type")) ? "DNA        " : "RNA        "));
+			result.append((!Type.RNA.equals(seq.get("type")) ? "DNA        " : "RNA        "));
 		    }
 		} else {
 		    result.append(" aa            ");
 		}
-		result.append((seq.getField("topology") != Topology.CIRCULAR ? "linear   "
+		result.append((!Topology.CIRCULAR.equals(seq.get("topology")) ? "linear   "
 			       : "circular "));
 		if (seq.containsKey("classification")) {
-		    result.append(seq.getField("classification")).append(" ");
+		    result.append(seq.get("classification")).append(" ");
 		} else {
 		    result.append("CON "); // division code + space
 		}
 		if (seq.containsKey("creation-date")) {
-		    result.append(seq.getField("creation-date"));
+		    result.append(seq.get("creation-date"));
 		} else {
 		    result.append((new SimpleDateFormat("dd-MMM-yyyy")).format(
 			    new Date()).toUpperCase());
 		}
 		result.append("\n");
-		if ( ! "".equals(seq.getField("accession"))) {
+		if ( ! "".equals(seq.get("accession"))) {
 		    result.append("ACCESSION   ").append(
-			    seq.getField("accession").toString()).append("\n");
+			    seq.get("accession").toString()).append("\n");
 		}
-		if ( ! "".equals(seq.getField("description"))) {
+		if ( ! "".equals(seq.get("description"))) {
 		    result.append("DESCRIPTION ").append(
-			    seq.getField("description").toString()).append("\n");
+			    seq.get("description").toString()).append("\n");
 		}
-		if ( ! "".equals(seq.getField("GI"))) {
-		    result.append("VERSION     ").append(( ! "".equals(seq.getField(
-			    "accession")) ? seq.getField("accession").toString() +
+		if ( ! "".equals(seq.get("GI"))) {
+		    result.append("VERSION     ").append(( ! "".equals(seq.get(
+			    "accession")) ? seq.get("accession").toString() +
 						      ".1" : "A00001.1") + " GI:" +
-							 seq.getField("GI").toString() +
+							 seq.get("GI").toString() +
 							 "\n");
 		}
 	    } else {
-                result.append(seq.getField("originalgb"));
+                result.append(seq.get("originalgb"));
             }
 	    result.append("ORIGIN");
 	    for (int count = 0; count < sequence.length(); count += 60) {
@@ -189,7 +190,7 @@ public class GenBankFile2008 extends DataFormat {
 			    result.add(new Sequence(sequence));
 			    sequence.clear();
 			    original = new StringBuffer();
-			    org.biolegato.core.main.BLMain.warning("Genbank entry missing // terminator", "GenBankFile2008.class");
+			    BLMain.warning("Genbank entry missing // terminator", "GenBankFile2008.class");
 			}
                         tokenz = new StringTokenizer(value);
                         if (tokenz.hasMoreTokens()) {
@@ -255,7 +256,7 @@ public class GenBankFile2008 extends DataFormat {
 	    sequence.put("originalgb", original);
 	    result.add(new Sequence(sequence));
 	    sequence.clear();
-	    org.biolegato.core.main.BLMain.warning("Genbank entry missing // terminator", "GenBankFile2008.class");
+	    BLMain.warning("Genbank entry missing // terminator", "GenBankFile2008.class");
 	}
         return result.toArray(new Sequence[0]);
     }
