@@ -24,7 +24,7 @@ if [ -d $FULLPATH  ]
 then
    cd $FULLPATH
    for file in `ls *.pdf *.ps *.doc *.txt *.asc *.PDF *.PS *.html *.htm *.HTML *.HTM\
-           *.man *.sxw *.sxc *.sxi *.odt`
+           *.man *.sxw *.sxc *.sxi *.odt README`
        do
 
 	 # Strip off leading path components, and retain the name of current directory    
