@@ -4,7 +4,7 @@
 "htmldoc.py - Create web pages for BIRCH documentation from birchdb database"
 
 # 
-# Version 4/ 2/08
+# Version 10/ 8/09
 #
 # Synopsis: htmldoc.py
 
@@ -286,12 +286,16 @@ def ReadProgram(FN,PROGS) :
 	     elif re.match('gui\s+".+"',LINE) :
 		PR.interface.append(['gui',GetStr(LINE)])
 	     elif re.match('GDE\s+".+"',LINE) :
+		PR.interface.append(['biolegato',GetStr(LINE)])	     
 		PR.interface.append(['GDE',GetStr(LINE)])
 	     elif re.match('dGDE\s+".+"',LINE) :
+		PR.interface.append(['dbiolegato',GetStr(LINE)])	     
 		PR.interface.append(['dGDE',GetStr(LINE)])
 	     elif re.match('mGDE\s+".+"',LINE) :
+		PR.interface.append(['mbiolegato',GetStr(LINE)])	     
 		PR.interface.append(['mGDE',GetStr(LINE)])
 	     elif re.match('tGDE\s+".+"',LINE) :
+		PR.interface.append(['tbiolegato',GetStr(LINE)])	     
 		PR.interface.append(['tGDE',GetStr(LINE)])
 	     elif re.match('Package\s+".+"',LINE) :
 		TOKENS = TOKENIZE(LINE)
